@@ -1,4 +1,4 @@
-from time import sleep, time
+from time import sleep, time, strftime, localtime
 import shelve
 import shlex
 from subprocess import STDOUT, Popen, PIPE
@@ -12,7 +12,8 @@ import json
 import sys
 import curses
 import os
-from livestreamer import Livestreamer
+
+import livestreamer
 
 PY3 = sys.version_info.major >= 3
 
@@ -22,8 +23,7 @@ else:
     import Queue as queue
 
 PROG_STRING    = 'livestreamer-curses'
-VERSION_STRING = '1.4.0'
-TITLE_STRING   = '{0} v{1}'.format(PROG_STRING, VERSION_STRING)
+TITLE_STRING   = 'v{{0}} with Livestreamer v{1}'.format(PROG_STRING, livestreamer.__version__)
 
 ID_FIELD_WIDTH   = 6
 NAME_FIELD_WIDTH = 22
@@ -31,17 +31,6 @@ RES_FIELD_WIDTH  = 12
 VIEWS_FIELD_WIDTH = 7
 PLAYING_FIELD_OFFSET = ID_FIELD_WIDTH + NAME_FIELD_WIDTH + RES_FIELD_WIDTH + VIEWS_FIELD_WIDTH + 6
 
-DEFAULT_RESOLUTION_HARD = '480p'
-
-INDICATORS = [
-        '  x  ', # offline
-        ' >>> ', # streaming
-        '  ?  ', # unknown
-        '  !  '  # error
-]
-
-CHECK_ONLINE_THREADS = 15
-
 class QueueFull(Exception): pass
 class QueueDuplicate(Exception): pass
 class ShelveError(Exception): pass
@@ -140,9 +129,11 @@ class StreamPlayer(object):
 
 class StreamList(object):
 
-    def __init__(self, filename, rc_module, list_streams=False, init_stream_list=None):
+    def __init__(self, filename, config, list_streams=False, init_stream_list=None):
         """ Init and try to load a stream list, nothing about curses yet """
 
+        global TITLE_STRING
+
         self.db_was_read = False
 
         # Open the storage (create it if necessary)
@@ -185,19 +176,17 @@ class StreamList(object):
         self.filter = ''
         self.all_streams_offline = None
         self.show_offline_streams = False
-        self.rc_module = rc_module
+        self.config = config
 
-        if 'LIVESTREAMER_COMMANDS' in dir(self.rc_module):
-            self.cmd_list = list(map(shlex.split, self.rc_module.LIVESTREAMER_COMMANDS))
-        else:
-            self.cmd_list = [['livestreamer']]
+        TITLE_STRING = TITLE_STRING.format(self.config.VERSION)
+
+        self.cmd_list = list(map(shlex.split, self.config.LIVESTREAMER_COMMANDS))
         self.cmd_index = 0
         self.cmd = self.cmd_list[self.cmd_index]
 
-        if 'DEFAULT_RESOLUTION' in dir(self.rc_module):
-            self.default_res = self.rc_module.DEFAULT_RESOLUTION
-        else:
-            self.default_res = DEFAULT_RESOLUTION_HARD
+        self.last_autocheck = 0
+
+        self.default_res = self.config.DEFAULT_RESOLUTION
 
         self.store = f
         self.store.sync()
@@ -206,7 +195,7 @@ class StreamList(object):
         self.no_stream_shown = self.no_streams
         self.q = ProcessList(StreamPlayer().play)
 
-        self.livestreamer = Livestreamer()
+        self.livestreamer = livestreamer.Livestreamer()
 
     def __del__(self):
         """ Stop playing streams and sync storage """
@@ -249,7 +238,7 @@ class StreamList(object):
 
         signal.signal(28, self.resize)
 
-        if 'CHECK_ONLINE_ON_START' in dir(self.rc_module) and self.rc_module.CHECK_ONLINE_ON_START:
+        if self.config.CHECK_ONLINE_ON_START:
             self.check_online_streams()
 
         self.set_status('Ready')
@@ -302,6 +291,16 @@ class StreamList(object):
                 (r, w, x) = select.select(souts, [], [], 1)
             except select.error:
                 continue
+            if not r:
+                if self.config.CHECK_ONLINE_INTERVAL <= 0: continue
+                cur_time = int(time())
+                time_delta = cur_time - self.last_autocheck
+                if time_delta > self.config.CHECK_ONLINE_INTERVAL:
+                    self.check_online_streams()
+                    self.set_status('Next check at {0}'.format(
+                        strftime('%H:%M:%S', localtime(time() + self.config.CHECK_ONLINE_INTERVAL))
+                        ))
+                continue
             for fd in r:
                 if fd != sys.stdin:
                     # Set the new status line only if non-empty
@@ -587,9 +586,9 @@ class StreamList(object):
         views  = '{0} '.format(stream['seen']).rjust(VIEWS_FIELD_WIDTH)
         p = self.q.get_process(stream['id']) != None
         if p:
-            indicator = '[>>>]'
+            indicator = self.config.INDICATORS[4] # playing
         else:
-            indicator = INDICATORS[stream['online']]
+            indicator = self.config.INDICATORS[stream['online']]
         return '{0} {1} {2} {3}   {4}'.format(idf, name, res, views, indicator)
 
     def redraw_current_line(self):
@@ -637,7 +636,7 @@ class StreamList(object):
                     else:
                         attr = curses.A_NORMAL
                     self.pads['streams'].addstr(i, PLAYING_FIELD_OFFSET,
-                                                INDICATORS[s['online']], attr)
+                                                self.config.INDICATORS[s['online']], attr)
                     self.refresh_current_pad()
 
     def _check_stream(self, url):
@@ -662,7 +661,7 @@ class StreamList(object):
             done_queue.put(url)
             return status
 
-        pool = Pool(CHECK_ONLINE_THREADS)
+        pool = Pool(self.config.CHECK_ONLINE_THREADS)
         args = [(s['url'], done_queue) for s in self.streams]
         statuses = pool.map_async(check_stream_managed, args)
         n_streams = len(self.streams)
@@ -679,6 +678,9 @@ class StreamList(object):
                 self.all_streams_offline = False
 
         self.refilter_streams()
+        self.last_autocheck = int(time())
+
+        pool.close()
 
     def prompt_input(self, prompt=''):
         self.s.move(self.max_y, 0)
